//Ici par contre on a besoin des définitions de classe complètes, et comme on ne les a pas mises dans le .h il faut le faire ici
//l'inclusion de <QtGui> est plus lourde, mais évite d'avoir à faire toutes les inclusions pour toutes les classes GUI de Qt
#include <QtGui>
#include "finddialog.h"

//La définition du constructeur permet de dire comment créer un objet; on voit ici que pour créer un objet de type FindDialog, on crée un objet de type QDialog avec même paramètre
// c'est le principe même de l'héritage
FindDialog::FindDialog(QWidget *parent)
        : QDialog(parent)
{
    //J'instancie les objets correspondant aux attributs de ma classe

    //Je crée ma ligne de saisie avec son label ??? le signe "&" indique ici que c'est cette lettre qui sera le raccourci clavier
    // mes chaînes de caractères à afficher sont précédées de "tr" en vue de l'intégration future d'une traduction
    label = new QLabel(tr("Find &what : "));
    lineEdit = new QLineEdit;
    //J'associe cette étiquette et cette ligne de saisie
        label->setBuddy(lineEdit);

    //création de deux cases à cocher;
    caseCheckBox = new QCheckBox(tr("Match &case"));
    backwardCheckBox = new QCheckBox(tr("Search &backward"));

    //Je crée le premier bouton qui à sa création est le bouton sélectionné par défaut mais n'est pas accessible
    findButton = new QPushButton(tr("&Find"));
        findButton->setDefault(true);
        findButton->setEnabled(false);

    closeButton = new QPushButton(tr("C&lose"));

    //Comme FindDialog hérite de QObject au travers de QDialog, je peux omettre ici les QObject::
    //Je déclare que dès que qch est mis dans la fenêtre de saisie, le bouton "Find" devient cliquable
    connect(lineEdit, SIGNAL(textChanged(const QString &)), this, SLOT(enableFindButton(const QString &)) );
    //Si on clique ce bouton, on appelle la fonction findClicked définie plus bas
    connect(findButton, SIGNAL(clicked()) , this, SLOT(findClicked()) );
    //Si on clique sur le bouton "close"
    connect(closeButton, SIGNAL(clicked()), this, SLOT(close()) );

    //Disposition des éléments dans des containeurs; à noter ici que findButton est à la fois dans deux containeurs, pour permettre son alignement avec ce qui est à gauche et ce qui est dessous
    QHBoxLayout *topLeftLayout = new QHBoxLayout;
        topLeftLayout->addWidget(findButton);
        topLeftLayout->addWidget(lineEdit);

    QVBoxLayout *leftLayout = new QVBoxLayout;
        leftLayout->addLayout(topLeftLayout);
        leftLayout->addWidget(caseCheckBox);
        leftLayout->addWidget(backwardCheckBox);

    QVBoxLayout *rightLayout = new QVBoxLayout;
        rightLayout->addWidget(findButton);
        rightLayout->addWidget(closeButton);
        rightLayout->addStretch();

    QHBoxLayout *mainLayout = new QHBoxLayout;
        mainLayout->addLayout(leftLayout);
        mainLayout->addLayout(rightLayout);

    // Je place mon conteneur principal (celui qui contient tous les autres) dans ma boite de dialogue
    this->setLayout(mainLayout);

    this->setWindowTitle(tr("Find"));
    // Je veux que ma fenêtre ait une hauteur "idéale"
    this->setFixedHeight(sizeHint().height());
}

//J'écris ici la fonction réactive (slot) dont j'avais déclaré le prototype dans le .h
void FindDialog::findClicked()
{
    // Je mets dans une variable QString le texte saisi par l'utilisateur
    QString maRecherche = lineEdit->text();
    // La ligne suivant se lit : la checkBox est-elle cochée ? Si oui je donne à cs la valeur "sensible à la casse", sinon la valeur "insensible à la casse"
    Qt::CaseSensitivity cs = caseCheckBox->isChecked() ? Qt::CaseSensitive : Qt::CaseInsensitive;

    // Si la case recherche en arrière (search backward) est cochée, alors quand je dois émettre le SIGNAL findClicked() j'émets le signal findPrevious avec comme paramètres la chaîne contenue
    // dans maRecherche à chercher, cs indiquant si je dois faire attention à la casse. Sinon j'émets pour findClicked() le signal findNext
    if(backwardCheckBox->isChecked())
    {
        emit findPrevious(maRecherche, cs);
    }
    else
    {
        emit findNext(maRecherche, cs);
    }
}

void FindDialog::enableFindButton(const QString &text)
{
    findButton->setEnabled(!text.isEmpty());
}

